package com.flywithu.carnav;

import android.annotation.TargetApi;
import android.app.Notification;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.media.MediaMetadata;
import android.media.session.MediaController;
import android.media.session.MediaSession;
import android.media.session.MediaSessionManager;
import android.media.session.PlaybackState;
import android.os.Bundle;
import android.os.IBinder;
import android.service.notification.NotificationListenerService;
import android.service.notification.StatusBarNotification;
import android.util.Log;

import androidx.annotation.Nullable;

import java.util.Arrays;
import java.util.List;

@TargetApi(21)
public class NotificationListenerMusic extends NotificationListenerService {
    String[] musicAppFilter = {"com.iloen.melon", "skplanet.musicmate"};

    @Override
    public IBinder onBind(Intent intent) {
        ComponentName componentName = new ComponentName(this, getClass());
        MediaSessionManager manager = (MediaSessionManager) this.getSystemService(Context.MEDIA_SESSION_SERVICE);

        manager.addOnActiveSessionsChangedListener(new MediaSessionManager.OnActiveSessionsChangedListener() {
            @Override
            public void onActiveSessionsChanged(@Nullable List<MediaController> controllers) {
                for (MediaController controller : controllers) {
                    if (controllers != null) {
                        try {

                            controller.registerCallback(new MediaController.Callback() {
                                MusicTitle currentSong = new MusicTitle();

                                private Intent getMusicIntent() {
                                    Intent music = new Intent("com.flywithu.carnav.metachanged");
                                    music.putExtra("artist", currentSong.getArtist());
                                    music.putExtra("album", currentSong.getAlbum());
                                    music.putExtra("track", currentSong.getTrack());
                                    music.putExtra("playstate", currentSong.isRunning());
                                    music.putExtra("position", currentSong.getPosition());
                                    music.putExtra("total", currentSong.getTotal());

                                    return music;
                                }

                                @Override
                                public void onQueueChanged(List<MediaSession.QueueItem> queue) {
                                    currentSong.setTotal(queue.size());
                                }

                                @Override
                                public void onPlaybackStateChanged(@Nullable PlaybackState state) {
                                    super.onPlaybackStateChanged(state);
                                    currentSong.setRunning(state.getState() == PlaybackState.STATE_PLAYING);
                                    currentSong.setPosition(state.getActiveQueueItemId());
                                    Log.d("NotificationMusic", "Playback");
                                    if (currentSong.getAlbum() != null) {
                                        sendBroadcast(getMusicIntent());
                                    }
                                }

                                @Override
                                public void onMetadataChanged(MediaMetadata metadata) {
                                    super.onMetadataChanged(metadata);
                                    currentSong.setArtist(metadata.getString(MediaMetadata.METADATA_KEY_ARTIST));
                                    currentSong.setTrack(metadata.getString(MediaMetadata.METADATA_KEY_TITLE));
                                    currentSong.setAlbum(metadata.getString(MediaMetadata.METADATA_KEY_ALBUM));


                                    sendBroadcast(getMusicIntent());
                                }
                            });

                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                    }
                }
            }
        }, componentName);

        return super.onBind(intent);
    }


    private void checkMusicStatus() {
        StatusBarNotification[] activeNotifications = getActiveNotifications();
        for (StatusBarNotification noti : activeNotifications) {
            if (Arrays.asList(musicAppFilter).contains(noti.getPackageName())) {
                Notification mytest = noti.getNotification();

                Bundle extras = noti.getNotification().extras;


                for (String a : extras.keySet()) {
                    Object value = extras.get(a);
                    if (value instanceof Boolean) {
                        Log.d("NotificationListener", "KEY:" + extras.getBoolean(a));
                    } else if (value instanceof Integer) {
                        Log.d("NotificationListener", "KEY:" + extras.getInt(a));
                    } else {
                        Log.d("NotificationListener", "KEY:" + a + "/" + extras.getString(a));
                    }

                }
//                CharSequence title = extras.getString(Notification.EXTRA_TITLE);
//                CharSequence artist = extras.getCharSequence(Notification.EXTRA_TEXT);
//                Log.d("NotificationListener","NAME:"+noti.getPackageName());
//                Log.i("NotificationListener", "[snowdeer] title:" + title);
//                Log.i("NotificationListener", "[snowdeer] artist:" + artist);

            }


            //   Log.d("TAG",noti.getNotification().getGroup());

        }


    }

    @Override
    public void onNotificationPosted(StatusBarNotification sbn) {
        checkMusicStatus();

    }

    @Override
    public void onNotificationRemoved(StatusBarNotification sbn) {
        checkMusicStatus();
    }


}
